Lookup
======

Problematic
-----------

How can we look for information about a given subject ?

Documentation
-------------

.. automodule:: PyFunceble.lookup
   :members:
   :private-members:

:code:`DNSLookup()`
^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.dns.DNSLookup
    :members:
    :private-members:

:code:`HTTPCode()`
^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.http_code.HTTPCode
    :members:
    :private-members:

:code:`Iana()`
^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.iana.Iana
    :members:
    :private-members:

:code:`PublicSuffix()`
^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.publicsuffix.PublicSuffix
    :members:
    :private-members:

:code:`Referer()`
^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.referer.Referer
    :members:
    :private-members:

:code:`HostSSLAdapter()`
^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.requests.HostSSLAdapter
    :members:
    :private-members:

:code:`HostAdapter()`
^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.requests.HostAdapter
    :members:
    :private-members:

:code:`IPv4Reputation`
^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.ipv4_reputation.IPv4Reputation
    :members:
    :private-members:

:code:`Requests()`
^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.requests.Requests
    :members:
    :private-members:

:code:`WhoisLookup()`
^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PyFunceble.lookup.whois.WhoisLookup
    :members:
    :private-members: